/************************************************************************
 *
 * Copyright (C) 2014-2022 IRCAD France
 * Copyright (C) 2014-2018 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include "modules/ui/qt/config.hpp"

#include <data/Camera.hpp>

#include <boost/bimap/bimap.hpp>

#include <QVideoFrame>

namespace sight::module::ui::qt::video
{

//-----------------------------------------------------------------------------

typedef boost::bimaps::bimap<QVideoFrame::PixelFormat, data::Camera::PixelFormat> PixelFormatTranslatorType;
extern MODULE_UI_QT_API PixelFormatTranslatorType pixelFormatTranslator;

} // namespace sight::module::ui::qt::video
